yt.visualization.plot_modifications.ContourCallback.convert_to_plot — The yt Project 3.2-dev documentation

# yt.visualization.plot_modifications.ContourCallback.convert_to_plot

`ContourCallback.` `convert_to_plot`(plot, coord, offset=True)

  Convert coordinates from projected data coordinates to PlotWindow plot coordinates. Projected data coordinates are two dimensional and refer to the location relative to the specific axes being plotted, although still in simulation units. PlotWindow plot coordinates are locations as found in the final plot, usually with the origin in the center of the image and the extent of the image defined by the final plot axis markers.